@@ -3,7 +3,7 @@
 name = 'omnifig'
 long_name = 'omni-fig'
 
-version = '0.5.8'
+version = '0.5.9'
 
 url = 'https://github.com/felixludos/omni-fig'
 
@@ -28,4 +28,4 @@ except:
 	install_requires = ['pyyaml', 'C3Linearize', 'humpack', 'omnibelt']
 del os
 
-entry_points = {'console_scripts': 'fig = omnifig.running:entry'}
\ No newline at end of file
+entry_points = {'console_scripts': 'fig = omnifig.top:entry'}
\ No newline at end of file
