@@ -2,9 +2,8 @@
 import sys, os
 from tabulate import tabulate
 
-from .external import view_config_registry
-from .registry import get_script, view_script_registry
 from .rules import Meta_Rule, view_meta_rules
+from .top import view_scripts, view_configs, find_script
 
 
 _default_help_msg = '''
@@ -67,9 +66,9 @@ def help_message(meta, config):
 	minfo = tabulate(metas, headers=['Code', 'Name', 'Description'], ) # tablefmt="plain"
 	
 	scripts = [(s.name, '-' if s.description is None else s.description)
-	           for s in view_script_registry().values()]#[:num]
+	           for s in view_scripts().values() if not s.name.startswith('_')]#[:num]
 	
-	configs = [c.name for c in view_config_registry().values()]
+	configs = [c.name for c in view_configs().values()]
 	
 	end = ''
 	if len(configs) > num:
@@ -90,7 +89,7 @@ def help_message(meta, config):
 	
 	else:
 		
-		info = get_script(name)
+		info = find_script(name)
 		doc = info.fn.__doc__
 	
 		if doc is None or len(doc) == 0:
