@@ -2,6 +2,7 @@
 import sys, os
 
 from .profiles import Profile
+from .util import global_settings
 
 from omnibelt import get_printer, resolve_order
 
@@ -15,13 +16,13 @@ _profile_cls = Profile
 
 def set_profile_cls(cls):
 	'''Set the class used when loading the profile'''
-	global _profile_cls
-	prt.debug(f'Profile cls used: {_profile_cls.__name__}')
-	_profile_cls = cls
+	prt.debug(f'Profile cls set to: {cls.__name__}')
+	global_settings['profile_cls'] = cls
+set_profile_cls(Profile) # default
 
 def get_profile_cls():
 	'''Get the class used when loading the profile'''
-	return _profile_cls
+	return global_settings['profile_cls']
 
 
 _profile = None
@@ -53,28 +54,21 @@ def load_profile(**overrides):
 	
 	return _profile
 
-
 def get_profile(**overrides):
 	'''Returns current profile (which gets loaded if there is None)'''
 	if _profile is None:
 		load_profile(**overrides)
 	return _profile
 
-def get_project(ident=None):
-	'''Checks the profile to return (and possibly load) a project given the name or path ``ident``'''
-	profile = get_profile()
-	if profile is not None:
-		return profile.get_project(ident=ident)
-
-
 class set_current_project:
 	'''Context manager to change set the current project in the context'''
 	def __init__(self, project=None):
-		self.prev = get_current_project()
-		self.new = project
-		
 		profile = get_profile()
-		profile.set_active_project(project)
+
+		self.prev = profile.get_current_project()
+		self.new = project if project is None else profile.get_project(project)
+		
+		profile.set_active_project(self.new)
 	
 	def __enter__(self):
 		pass
@@ -82,19 +76,9 @@ class set_current_project:
 	def __exit__(self, exc_type, exc_value, exc_traceback):
 		set_current_project(self.prev)
 
-
 def clear_current_project():
 	'''Unset the current project (setting it to None)'''
 	set_current_project()
 
 
-def get_current_project():
-	'''Get the current project, assuming a profile is loaded, otherwise returns None'''
-	profile = get_profile()
-	if profile is not None:
-		return profile.get_current_project()
-
-
-
-
 
